/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IPoolConfiguration.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.pool.api;

/**
 * Defines the attributes that can be set on the pool in order to configure it.
 * @author Florent BENOIT
 */
public interface IPoolConfiguration {

    /**
     * Default max is unlimited.
     */
    int DEFAULT_MAX = -1;

    /**
     * Default timeout = 10 second.
     */
    long DEFAULT_TIMEOUT = 10000L;

    /**
     * Default max waiters = 1000.
     */
    int DEFAULT_MAX_WAITERS = 1000;

    /**
     * @return Maximum size of the pool.
     */
    int getMax();

    /**
     * Sets the Maximum size of the pool.
     * @param max the given maximum size of the pool
     */
    void setMax(final int max);

    /**
     * @return the timeout for waiters that are waiting for an empty element in the pool.
     */
    long getTimeout();

    /**
     * Sets the timeout for waiters that are waiting for an empty element in the pool..
     * @param timeout the timeout for waiters that are waiting for an empty element in the pool.
     */
    void setTimeout(final long timeout);

    /**
     * @return the number of waiters that can wait for the given timeout. If this number is
     * reached, there is no wait and an exception is thrown.
     */
    int getMaxWaiters();

    /**
     * Sets the number of waiters that can wait for the given timeout.
     * @param maxWaiters the number of waiters that can wait for the given timeout.
     */
    void setMaxWaiters(final int maxWaiters);


}
